@@ -38,7 +38,7 @@ from uuid import uuid4 as uuid
 import remt
 from .error import *
 from .indexer import ann_text, fmt_ann_text
-from .meta import BASE_DIR, fn_path, read_meta, fn_metadata
+from .meta import BASE_DIR, fn_path, read_meta, fn_metadata, create_metadata
 from .pdf import pdf_open
 from .util import flatten
 
