@@ -1,7 +1,7 @@
 #
 # remt - reMarkable tablet command-line tools
 #
-# Copyright (C) 2018-2019 by Artur Wroblewski <wrobell@riseup.net>
+# Copyright (C) 2018-2020 by Artur Wroblewski <wrobell@riseup.net>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,6 +17,8 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
+import cairo
+import typing as tp
 from collections import namedtuple
 
 Page = namedtuple('Page', ['number'])
@@ -32,11 +34,20 @@ Segment = namedtuple(
     ['number', 'x', 'y', 'speed', 'direction', 'width', 'pressure'],
 )
 
-Style = namedtuple(
-    'Style',
-    ['color', 'join', 'cap', 'brush', 'tool_line']
-)
-Color = namedtuple('Color', ['red', 'green', 'blue', 'alpha'])
+class Color(tp.NamedTuple):
+    red: float
+    green: float
+    blue: float
+    alpha: float
+
+class Style(tp.NamedTuple):
+    tool_line: tp.Callable
+    color: Color
+    join: cairo.LineJoin
+    cap: cairo.LineCap
+    dash: tp.List[int] = []
+    brush: tp.Optional[str] = None
+
 Context = namedtuple(
     'Context',
     ['cr_surface', 'cr_ctx', 'pdf_doc', 'page_number']
