@@ -1,7 +1,7 @@
 #
 # remt - reMarkable tablet command-line tools
 #
-# Copyright (C) 2018-2019 by Artur Wroblewski <wrobell@riseup.net>
+# Copyright (C) 2018-2020 by Artur Wroblewski <wrobell@riseup.net>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@ import itertools
 import logging
 import os.path
 import pkgutil
+from collections import defaultdict
 from contextlib import contextmanager
 from functools import singledispatch, lru_cache, partial
 
@@ -45,32 +46,30 @@ COLOR_STROKE = {
 COLOR_HIGHLIGHTER = Color(1.0, 0.8039, 0.0, 0.1)
 
 STYLE_DEFAULT = Style(
-    None,
+    tool.single_line,
+    COLOR_STROKE[0],
     cairo.LINE_JOIN_ROUND,
     cairo.LINE_CAP_ROUND,
-    None,
-    tool.single_line,
 )
+style_default = STYLE_DEFAULT._replace
 
 STYLE_HIGHLIGHTER = Style(
+    tool.line_highlighter,
     COLOR_HIGHLIGHTER,
     cairo.LINE_JOIN_ROUND,
     cairo.LINE_CAP_SQUARE,
-    None,
-    tool.line_highlighter,
 )
 
 STYLE_ERASER = Style(
+    tool.line_eraser,
     COLOR_STROKE[2],
     cairo.LINE_JOIN_ROUND,
     cairo.LINE_CAP_ROUND,
-    None,
-    tool.line_eraser,
 )
 
-style_default = STYLE_DEFAULT._replace
+STYLE_UNKNOWN_TOOL = style_default(tool_line=tool.line_unknown, dash=[1, 5])
 
-STYLE = {
+STYLE = defaultdict(lambda: STYLE_UNKNOWN_TOOL, {
     # Brush, pencil tilt and marker - tilt dependent
     # 0: lambda st: Style(
     #     (5 * st.tilt) * (6 * st.width - 10) * (1 + 2 * st.pressure ** 3),
@@ -96,22 +95,26 @@ STYLE = {
 
     # Ballpoint
     2: style_default(tool_line=tool.line_ballpoint),
+    15: style_default(tool_line=tool.line_ballpoint),
 
     # Fineliner
     4: style_default(tool_line=tool.line_fineliner),
+    17: style_default(tool_line=tool.line_fineliner),
 
     # Highlighter
     5: STYLE_HIGHLIGHTER,
+    18: STYLE_HIGHLIGHTER,
 
     # Eraser
     6: STYLE_ERASER,
 
     # Sharp pencil
     7: style_default(tool_line=tool.line_sharp_pencil, brush='pencil.png'),
+    13: style_default(tool_line=tool.line_sharp_pencil, brush='pencil.png'),
 
     # Erase area
     8: STYLE_ERASER._replace(tool_line=tool.line_erase_area),
-}
+})
 
 
 path_brush = partial(os.path.join, 'brush')
@@ -161,10 +164,9 @@ def _(layer, context):
 
 @draw.register(Stroke)
 def _(stroke, context):
-    style = STYLE.get(stroke.pen)
-    if not style:
+    style = STYLE[stroke.pen]
+    if style is STYLE_UNKNOWN_TOOL:
         logger.debug('Not supported pen for stroke: {}'.format(stroke))
-        return
 
     # if no predefined style color, then use stroke color
     assert stroke.color in (0, 1, 2)
@@ -180,6 +182,9 @@ def _(stroke, context):
     cr.set_line_join(style.join)
     cr.set_line_cap(style.cap)
 
+    if style.dash:
+        cr.set_dash(style.dash, 0)
+
     if style.brush:
         brush = load_brush(style.brush)
         cr.set_source(brush)
