@@ -1,7 +1,7 @@
 #
 # remt - reMarkable tablet command-line tools
 #
-# Copyright (C) 2018-2019 by Artur Wroblewski <wrobell@riseup.net>
+# Copyright (C) 2018-2020 by Artur Wroblewski <wrobell@riseup.net>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,14 +30,6 @@ from remt.error import *
 import pytest
 from unittest import mock
 
-def test_fn_path():
-    """
-    Test creating UUID based path from metadata.
-    """
-    meta = {'uuid': 'xyz'}
-    result = r_cmd.fn_path(meta, base='/x/y', ext='.met')
-    assert '/x/y/xyz.met' == result
-
 def test_ls_line():
     """
     Test creating `ls` command basic output line.
@@ -130,51 +122,4 @@ def test_norm_path_leading_slashes():
     result = r_cmd.norm_path('///a//b/c//d///')
     assert 'a/b/c/d' == result
 
-def test_fn_metadata_error():
-    """
-    Test if error is raised if there is no metadata for a path.
-    """
-    meta = {'a/b/': 1}
-
-    with pytest.raises(FileError):
-        r_cmd.fn_metadata(meta, 'x/y')
-
-@pytest.mark.asyncio
-async def test_read_meta():
-    """
-    Test reading metadata.
-    """
-    sftp = mock.MagicMock()
-    sftp.mget = mock.AsyncMock()
-    dir_meta = 'dir'
-
-    with mock.patch('glob.glob') as mock_glob, \
-            mock.patch('json.load') as mock_json_load, \
-            mock.patch('builtins.open') as mock_open:  # noqa: F841
-
-        mock_glob.side_effect = [
-            # let's make read_meta resistant to some filesystem
-            # inconsistencies by introducing non-matching files
-            ['f1.content', 'f2.content', 'f3.content', 'f5.content'],
-            ['f1.metadata', 'f2.metadata', 'f3.metadata', 'f4.metadata'],
-        ]
-        mock_json_load.side_effect = [
-            {'visibleName': 'f1', 'deleted': False},
-            {'pages': 3},
-
-            # deleted filename shall not be visible in the results
-            {'visibleName': 'f2', 'deleted': True},
-            {'pages': 4},
-
-            {'visibleName': 'f3'},
-            {'pages': 5},
-            {'visibleName': 'f4'},
-            {'pages': 6},
-        ]
-        result = await r_cmd.read_meta(sftp, dir_meta)
-        assert ['f1', 'f2', 'f3'] == list(result)
-        assert {'pages': 3} == result['f1']['content']
-        assert {'pages': 4} == result['f2']['content']
-        assert {'pages': 5} == result['f3']['content']
-
 # vim: sw=4:et:ai
